@@ -150,6 +150,53 @@ class Tag(ReloadObj):
         self._raw.delete_tag_id(self.id)
 
 
+class Command(ReloadObj):
+    """ Represents a single Command.
+
+        Attributes:
+            name (str): Name.
+            commandName (str): Full named.
+            message (str): Status Message.
+            body (dict): Body of dict sent with the command.
+            priority (str): Priority level.
+            status (str): Status state.
+            queued (datetime): Datetime queued.
+            started (datetime): Datetime started.
+            ended (datetime): Datetime ended.
+            duration (str): Duration.
+            exception (str): Exception message if there is a failure.
+            trigger (str): Command trigger.
+            stateChangeTime (datetime): Datetime the sate was cahnged.
+            sendUpdatesToClient (bool): Send Updates To Client.
+            updateScheduledTask (bool):Update Scheduled Task.
+            id (int): ID of the Command.
+    """
+
+    def _load(self, data):
+        super()._load(data)
+        self.name = self._parse(attrs="name")
+        self.commandName = self._parse(attrs="commandName")
+        self.message = self._parse(attrs="message")
+        self.body = self._parse(attrs="body", value_type="dict")
+        self.priority = self._parse(attrs="priority")
+        self.status = self._parse(attrs="status")
+        self.queued = self._parse(attrs="queued", value_type="date")
+        self.started = self._parse(attrs="started", value_type="date")
+        self.ended = self._parse(attrs="ended", value_type="date")
+        self.duration = self._parse(attrs="duration")
+        self.exception = self._parse(attrs="exception")
+        self.trigger = self._parse(attrs="trigger")
+        self.sendUpdatesToClient = self._parse(attrs="sendUpdatesToClient", value_type="bool")
+        self.updateScheduledTask = self._parse(attrs="updateScheduledTask", value_type="bool")
+        self.stateChangeTime = self._parse(attrs="stateChangeTime", value_type="date")
+        self.lastExecutionTime = self._parse(attrs="lastExecutionTime", value_type="date")
+        self.id = self._parse(attrs="id", value_type="int")
+        self._finish(self.name)
+
+    def _full_load(self):
+        return self._raw.get_command_id(self.id)
+
+
 class Movie(ReloadObj):
     """ Represents a single Movie.
 
@@ -162,6 +209,8 @@ class Movie(ReloadObj):
             overview (str): Overview of the Movie.
             inCinemas (datetime): Date the Movie was in Cinemas.
             physicalRelease (datetime): Date the Movie was Physically Released.
+            digitalRelease (datetime): Date the Movie was Digitally Released.
+            images (List[:class:`~arrapi.objs.simple.Image`]): List of Images for the Movie.
             website (str): Website of the Movie.
             year (int): Year of the Movie.
             hasFile (bool): If the Movie has a file.
@@ -181,6 +230,7 @@ class Movie(ReloadObj):
             certification (str): Certification of the Movie.
             genres (List[str]): List of genres for the Movie.
             tags (List[:class:`~arrapi.objs.reload.Tag`]): List of tags for the Movie.
+            added (datetime): Date the Movie was added to Radarr.
             tagsIds (List[int]): List of tag ids for the Movie.
             rating_votes (int): Number of votes for the Movie.
             rating_value (float): Rating of the Movie.
@@ -211,6 +261,8 @@ class Movie(ReloadObj):
         self.overview = self._parse(attrs="overview")
         self.inCinemas = self._parse(attrs="inCinemas", value_type="date")
         self.physicalRelease = self._parse(attrs="physicalRelease", value_type="date")
+        self.digitalRelease = self._parse(attrs="digitalRelease", value_type="date")
+        self.images = self._parse(attrs="images", value_type="image", is_list=True)
         self.website = self._parse(attrs="website")
         self.year = self._parse(attrs="year", value_type="int")
         self.hasFile = self._parse(attrs="hasFile", value_type="bool")
@@ -231,8 +283,10 @@ class Movie(ReloadObj):
         self.genres = self._parse(attrs="genres", is_list=True)
         self.tagsIds = self._parse(attrs="tags", value_type="int", is_list=True)
         self.tags = self._parse(attrs="tags", value_type="intTag", is_list=True)
+        self.added = self._parse(attrs="added", value_type="date")
         self.rating_votes = self._parse(attrs=["rating", "votes"], value_type="int")
         self.rating_value = self._parse(attrs=["rating", "value"], value_type="float")
+        self.collection = self._parse(attrs="collection", value_type="collection")
         self.id = self._parse(attrs="id", value_type="int", default_is_none=True)
         if self._raw.v3:
             self.originalTitle = self._parse(attrs="originalTitle")
@@ -389,6 +443,7 @@ class Series(ReloadObj):
             previousAiring (datetime): Date the latest Episode in the Series Aired.
             network (str): Network the Series Airs on.
             airTime (str): Time Series Airs.
+            images (List[:class:`~arrapi.objs.simple.Image`]): List of Images for the Series.
             year (int): Year of the Series.
             path (str): Path of the Series.
             languageProfileId (int): Language Profile ID of the Series.
@@ -409,6 +464,7 @@ class Series(ReloadObj):
             certification (str): Certification of the Series.
             genres (List[str]): List of genres for the Series.
             tags (List[:class:`~arrapi.objs.reload.Tag`]): List of tags for the Movie.
+            added (datetime): Date the Movie was added to Radarr.
             tagsIds (List[int]): List of tag ids for the Movie.
             rating_votes (int): Number of votes for the Series.
             rating_value (float): Rating of the Series.
@@ -442,6 +498,7 @@ class Series(ReloadObj):
         self.previousAiring = self._parse(attrs="previousAiring", value_type="date")
         self.network = self._parse(attrs="network")
         self.airTime = self._parse(attrs="airTime")
+        self.images = self._parse(attrs="images", value_type="image", is_list=True)
         self.year = self._parse(attrs="year", value_type="int")
         self.path = self._parse(attrs="path")
         self.languageProfileId = self._parse(attrs="languageProfileId", value_type="int")
@@ -463,6 +520,7 @@ class Series(ReloadObj):
         self.genres = self._parse(attrs="genres", is_list=True)
         self.tagsIds = self._parse(attrs="tags", value_type="int", is_list=True)
         self.tags = self._parse(attrs="tags", value_type="intTag", is_list=True)
+        self.added = self._parse(attrs="added", value_type="date")
         if "rating" in self._data:
             self.rating_votes = self._parse(attrs=["rating", "votes"], value_type="int")
             self.rating_value = self._parse(attrs=["rating", "value"], value_type="float")
@@ -624,11 +682,11 @@ class Series(ReloadObj):
                 self._data[key] = value
         self._load(self._raw.put_series_id(self.id, self._data, moveFiles=valid_move_files))
 
-    def delete(self, addImportExclusion: bool = False, deleteFiles: bool = False) -> None:
+    def delete(self, addImportListExclusion: bool = False, deleteFiles: bool = False) -> None:
         """ Delete this Series from Sonarr.
 
             Parameters:
-                addImportExclusion (bool): Add Import Exclusion for this Series.
+                addImportListExclusion (bool): Add Import Exclusion for this Series.
                 deleteFiles (bool): Delete Files for this Series.
 
             Raises:
@@ -636,7 +694,7 @@ class Series(ReloadObj):
         """
         if not self.id:
             raise NotFound(f"{self.title} not found in Sonarr, it must be added before deleting")
-        self._raw.delete_series_id(self.id, addImportExclusion=addImportExclusion, deleteFiles=deleteFiles)
+        self._raw.delete_series_id(self.id, addImportListExclusion=addImportListExclusion, deleteFiles=deleteFiles)
         self._loading = True
         self.id = None
         self._loading = False
